pub struct IssueRelationDeleteArguments {
pub id: String,
}Fields
id: StringTrait Implementations
Sourceimpl Clone for IssueRelationDeleteArguments
impl Clone for IssueRelationDeleteArguments
Sourcefn clone(&self) -> IssueRelationDeleteArguments
fn clone(&self) -> IssueRelationDeleteArguments
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IssueRelationDeleteArguments
impl Debug for IssueRelationDeleteArguments
Sourceimpl QueryVariables for IssueRelationDeleteArguments
impl QueryVariables for IssueRelationDeleteArguments
Sourceconst VARIABLES: &'static [(&'static str, VariableType)]
const VARIABLES: &'static [(&'static str, VariableType)]
An associated constant that contains the variable names & their types. Read more
Sourcetype Fields = IssueRelationDeleteArgumentsFields
type Fields = IssueRelationDeleteArgumentsFields
A struct that determines which variables are available when using this
struct.