pub struct IssueUpdateArguments {
pub id: String,
pub input: IssueUpdateInput,
}Fields
id: Stringinput: IssueUpdateInputTrait Implementations
Sourceimpl Clone for IssueUpdateArguments
impl Clone for IssueUpdateArguments
Sourcefn clone(&self) -> IssueUpdateArguments
fn clone(&self) -> IssueUpdateArguments
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IssueUpdateArguments
impl Debug for IssueUpdateArguments
Sourceimpl QueryVariables for IssueUpdateArguments
impl QueryVariables for IssueUpdateArguments
Sourceconst VARIABLES: &'static [(&'static str, VariableType)]
const VARIABLES: &'static [(&'static str, VariableType)]
An associated constant that contains the variable names & their types. Read more
Sourcetype Fields = IssueUpdateArgumentsFields
type Fields = IssueUpdateArgumentsFields
A struct that determines which variables are available when using this
struct.