pub struct IssueCommentsArguments {
pub id: String,
pub first: Option<i32>,
pub after: Option<String>,
}Fields
id: Stringfirst: Option<i32>after: Option<String>Trait Implementations
Sourceimpl Clone for IssueCommentsArguments
impl Clone for IssueCommentsArguments
Sourcefn clone(&self) -> IssueCommentsArguments
fn clone(&self) -> IssueCommentsArguments
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IssueCommentsArguments
impl Debug for IssueCommentsArguments
Sourceimpl QueryVariables for IssueCommentsArguments
impl QueryVariables for IssueCommentsArguments
Sourceconst VARIABLES: &'static [(&'static str, VariableType)]
const VARIABLES: &'static [(&'static str, VariableType)]
An associated constant that contains the variable names & their types. Read more
Sourcetype Fields = IssueCommentsArgumentsFields
type Fields = IssueCommentsArgumentsFields
A struct that determines which variables are available when using this
struct.