pub struct IssueLabelsArguments {
pub first: Option<i32>,
pub after: Option<String>,
pub filter: Option<IssueLabelFilter>,
}Fields
first: Option<i32>after: Option<String>filter: Option<IssueLabelFilter>Trait Implementations
Sourceimpl Clone for IssueLabelsArguments
impl Clone for IssueLabelsArguments
Sourcefn clone(&self) -> IssueLabelsArguments
fn clone(&self) -> IssueLabelsArguments
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IssueLabelsArguments
impl Debug for IssueLabelsArguments
Sourceimpl QueryVariables for IssueLabelsArguments
impl QueryVariables for IssueLabelsArguments
Sourceconst VARIABLES: &'static [(&'static str, VariableType)]
const VARIABLES: &'static [(&'static str, VariableType)]
An associated constant that contains the variable names & their types. Read more
Sourcetype Fields = IssueLabelsArgumentsFields
type Fields = IssueLabelsArgumentsFields
A struct that determines which variables are available when using this
struct.