pub struct ProjectsArguments {
pub first: Option<i32>,
pub after: Option<String>,
pub filter: Option<ProjectFilter>,
}Fields
first: Option<i32>after: Option<String>filter: Option<ProjectFilter>Trait Implementations
Sourceimpl Clone for ProjectsArguments
impl Clone for ProjectsArguments
Sourcefn clone(&self) -> ProjectsArguments
fn clone(&self) -> ProjectsArguments
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectsArguments
impl Debug for ProjectsArguments
Sourceimpl QueryVariables for ProjectsArguments
impl QueryVariables for ProjectsArguments
Sourceconst VARIABLES: &'static [(&'static str, VariableType)]
const VARIABLES: &'static [(&'static str, VariableType)]
An associated constant that contains the variable names & their types. Read more
Sourcetype Fields = ProjectsArgumentsFields
type Fields = ProjectsArgumentsFields
A struct that determines which variables are available when using this
struct.