pub struct SearchIssuesArguments {
pub term: String,
pub include_comments: Option<bool>,
pub first: Option<i32>,
pub after: Option<String>,
pub filter: Option<IssueFilter>,
}Fields
term: Stringinclude_comments: Option<bool>first: Option<i32>after: Option<String>filter: Option<IssueFilter>Trait Implementations
Sourceimpl Clone for SearchIssuesArguments
impl Clone for SearchIssuesArguments
Sourcefn clone(&self) -> SearchIssuesArguments
fn clone(&self) -> SearchIssuesArguments
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchIssuesArguments
impl Debug for SearchIssuesArguments
Sourceimpl QueryVariables for SearchIssuesArguments
impl QueryVariables for SearchIssuesArguments
Sourceconst VARIABLES: &'static [(&'static str, VariableType)]
const VARIABLES: &'static [(&'static str, VariableType)]
An associated constant that contains the variable names & their types. Read more
Sourcetype Fields = SearchIssuesArgumentsFields
type Fields = SearchIssuesArgumentsFields
A struct that determines which variables are available when using this
struct.