pub struct TeamsArguments {
pub first: Option<i32>,
pub after: Option<String>,
pub filter: Option<TeamFilter>,
}Fields
first: Option<i32>after: Option<String>filter: Option<TeamFilter>Trait Implementations
Sourceimpl Clone for TeamsArguments
impl Clone for TeamsArguments
Sourcefn clone(&self) -> TeamsArguments
fn clone(&self) -> TeamsArguments
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TeamsArguments
impl Debug for TeamsArguments
Sourceimpl QueryVariables for TeamsArguments
impl QueryVariables for TeamsArguments
Sourceconst VARIABLES: &'static [(&'static str, VariableType)]
const VARIABLES: &'static [(&'static str, VariableType)]
An associated constant that contains the variable names & their types. Read more
Sourcetype Fields = TeamsArgumentsFields
type Fields = TeamsArgumentsFields
A struct that determines which variables are available when using this
struct.