pub struct UsersArguments {
pub first: Option<i32>,
pub after: Option<String>,
pub filter: Option<UserFilter>,
}Fields
first: Option<i32>after: Option<String>filter: Option<UserFilter>Trait Implementations
Sourceimpl Clone for UsersArguments
impl Clone for UsersArguments
Sourcefn clone(&self) -> UsersArguments
fn clone(&self) -> UsersArguments
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UsersArguments
impl Debug for UsersArguments
Sourceimpl QueryVariables for UsersArguments
impl QueryVariables for UsersArguments
Sourceconst VARIABLES: &'static [(&'static str, VariableType)]
const VARIABLES: &'static [(&'static str, VariableType)]
An associated constant that contains the variable names & their types. Read more
Sourcetype Fields = UsersArgumentsFields
type Fields = UsersArgumentsFields
A struct that determines which variables are available when using this
struct.