pub struct WorkflowStatesArguments {
pub first: Option<i32>,
pub after: Option<String>,
pub filter: Option<WorkflowStateFilter>,
}Fields
first: Option<i32>after: Option<String>filter: Option<WorkflowStateFilter>Trait Implementations
Sourceimpl Clone for WorkflowStatesArguments
impl Clone for WorkflowStatesArguments
Sourcefn clone(&self) -> WorkflowStatesArguments
fn clone(&self) -> WorkflowStatesArguments
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkflowStatesArguments
impl Debug for WorkflowStatesArguments
Sourceimpl QueryVariables for WorkflowStatesArguments
impl QueryVariables for WorkflowStatesArguments
Sourceconst VARIABLES: &'static [(&'static str, VariableType)]
const VARIABLES: &'static [(&'static str, VariableType)]
An associated constant that contains the variable names & their types. Read more
Sourcetype Fields = WorkflowStatesArgumentsFields
type Fields = WorkflowStatesArgumentsFields
A struct that determines which variables are available when using this
struct.