Module types

Module types 

Structs

Issue
IssueComment
Full comment fragment for reading issue comments. Named IssueComment to avoid conflict with minimal Comment in mutations.rs.
IssueCommentConnection
Connection type for issue comments query.
IssueConnection
IssueLabel
IssueLabelConnection
IssueSearchPayload
IssueSearchResult
IssueSearchResult from searchIssues query - has issue fields directly. NOTE: Duplicates subset of Issue fields; keep in sync. Nullability differs (e.g., state is non-null here).
PageInfo
ParentIssue
Minimal parent issue fragment to avoid recursive Issue expansion.
Project
ProjectConnection
Team
TeamConnection
User
UserConnection
WorkflowState
WorkflowStateConnection