pub struct IssueComment {
pub id: Id,
pub body: String,
pub url: String,
pub created_at: DateTime,
pub updated_at: DateTime,
pub parent_id: Option<String>,
pub user: Option<User>,
}Expand description
Full comment fragment for reading issue comments.
Named IssueComment to avoid conflict with minimal Comment in mutations.rs.
Fields
id: Idbody: Stringurl: Stringcreated_at: DateTimeupdated_at: DateTimeparent_id: Option<String>user: Option<User>Trait Implementations
Sourceimpl Clone for IssueComment
impl Clone for IssueComment
Sourcefn clone(&self) -> IssueComment
fn clone(&self) -> IssueComment
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IssueComment
impl Debug for IssueComment
Sourceimpl<'de> Deserialize<'de> for IssueComment
impl<'de> Deserialize<'de> for IssueComment
Sourcefn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl QueryFragment for IssueComment
impl QueryFragment for IssueComment
Sourcetype SchemaType = Comment
type SchemaType = Comment
The type in a schema that this
QueryFragment representsSourcetype VariablesFields = ()
type VariablesFields = ()
The variables that are required to execute this
QueryFragmentSourcefn query(builder: SelectionBuilder<'_, Self::SchemaType, Self::VariablesFields>)
fn query(builder: SelectionBuilder<'_, Self::SchemaType, Self::VariablesFields>)
Adds this fragment to the query being built by
builderAuto Trait Implementations
impl Freeze for IssueComment
impl RefUnwindSafe for IssueComment
impl Send for IssueComment
impl Sync for IssueComment
impl Unpin for IssueComment
impl UnsafeUnpin for IssueComment
impl UnwindSafe for IssueComment