pub struct ParentIssue {
pub id: Id,
pub identifier: String,
}Expand description
Minimal parent issue fragment to avoid recursive Issue expansion.
Fields
id: Ididentifier: StringTrait Implementations
Sourceimpl Clone for ParentIssue
impl Clone for ParentIssue
Sourcefn clone(&self) -> ParentIssue
fn clone(&self) -> ParentIssue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParentIssue
impl Debug for ParentIssue
Sourceimpl<'de> Deserialize<'de> for ParentIssue
impl<'de> Deserialize<'de> for ParentIssue
Sourcefn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl QueryFragment for ParentIssue
impl QueryFragment for ParentIssue
Sourcetype SchemaType = Issue
type SchemaType = Issue
The type in a schema that this
QueryFragment representsSourcetype VariablesFields = ()
type VariablesFields = ()
The variables that are required to execute this
QueryFragmentSourcefn query(builder: SelectionBuilder<'_, Self::SchemaType, Self::VariablesFields>)
fn query(builder: SelectionBuilder<'_, Self::SchemaType, Self::VariablesFields>)
Adds this fragment to the query being built by
builderAuto Trait Implementations
impl Freeze for ParentIssue
impl RefUnwindSafe for ParentIssue
impl Send for ParentIssue
impl Sync for ParentIssue
impl Unpin for ParentIssue
impl UnsafeUnpin for ParentIssue
impl UnwindSafe for ParentIssue